==> aptitude_0.2.11.1.orig.tar.gz: aptitude-0.2.11.1/src/pkg_node.h <==
// pkg_node.h	-*-c++-*-
//
//  Copyright 1999 Daniel Burrows
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING.  If not, write to
//  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//  Boston, MA 02111-1307, USA.
//
//  In the fine tradition of breaking header files up into their smallest
// usable components..

#ifndef PKG_NODE_H
#define PKG_NODE_H

#include <vscreen/vs_treeitem.h>
#include <generic/undo.h>

class undo_group;
class keybindings;

class pkg_tree_node:virtual public vs_treeitem
// Provides some extra package-related interfaces.
{
public:
  virtual void select(undo_group *undo)=0;
  virtual void hold(undo_group *undo)=0;
  virtual void remove(undo_group *undo)=0;
  virtual void purge(undo_group *undo)=0;
  virtual void reinstall(undo_group *unfo)=0;
  // set_auto is idempotent!  No stupid toggling stuff.
  virtual void set_auto(bool isauto, undo_group *undo)=0;
  // Any undo information needed should be added to the passed-in undo group

  bool dispatch_char(chtype ch, vs_tree *owner);
  // IMPORTANT NOTE: pkg_tree_node::dispatch_char() does NOT call
  // vs_treeitem::dispatch_char!

  static keybindings *bindings;
  static void init_bindings();
};

class apt_undo_group:public undo_group
{
public:
  void undo();
};

#endif

==> aptitude_0.2.15.9.orig.tar.gz: aptitude-0.2.15.9/src/pkg_node.h <==
// pkg_node.h	-*-c++-*-
//
//  Copyright 1999 Daniel Burrows
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING.  If not, write to
//  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//  Boston, MA 02111-1307, USA.
//
//  In the fine tradition of breaking header files up into their smallest
// usable components..

#ifndef PKG_NODE_H
#define PKG_NODE_H

#include <vscreen/vs_treeitem.h>
#include <generic/undo.h>

class undo_group;
class keybindings;

class pkg_tree_node:virtual public vs_treeitem
// Provides some extra package-related interfaces.
{
public:
  virtual void select(undo_group *undo)=0;
  virtual void hold(undo_group *undo)=0;
  virtual void keep(undo_group *undo)=0;
  virtual void remove(undo_group *undo)=0;
  virtual void purge(undo_group *undo)=0;
  virtual void reinstall(undo_group *undo)=0;
  // set_auto is idempotent!  No stupid toggling stuff.
  virtual void set_auto(bool isauto, undo_group *undo)=0;

  void mark_auto(undo_group *undo) {set_auto(true, undo);}
  void unmark_auto(undo_group *undo) {set_auto(false, undo);}

  bool dispatch_char(chtype ch, vs_tree *owner);
  // IMPORTANT NOTE: pkg_tree_node::dispatch_char() does NOT call
  // vs_treeitem::dispatch_char!

  static keybindings *bindings;
  static void init_bindings();
};

#endif
